@@ -259,6 +259,8 @@ class Update(MethodsInterface):
 
     def raiseOutdate(self):
         self.clVars.Set('cl_update_outdate_set', 'on', force=True)
+        if self.clVars.Get('cl_update_other_set') == 'auto':
+            self.clVars.Set('cl_update_other_set', 'on')
 
     def setAutocheckParams(self, status, interval, update_other, cleanpkg):
         """
@@ -402,9 +404,9 @@ class Update(MethodsInterface):
         saved_host = dv.Get('cl_update_rep_hosting') if 'cl_update_rep_hosting' in dv.allVars else ''
         working_host = ''
         # проверка необходимости синхронизации других оверлеев
-        if dv.Get("cl_update_inner_other_set") != 'auto':
-            dv.Write("cl_update_other_set", dv.Get("cl_update_inner_other_set"), header="update")
-            dv.Set("cl_update_other_set", dv.Get("cl_update_inner_other_set"))
+        #if dv.Get("cl_update_other_set") != 'auto':
+            #dv.Write("cl_update_other_set", dv.Get("cl_update_inner_other_set"), header="update")
+            #dv.Set("cl_update_other_set", dv.Get("cl_update_inner_other_set"))
         if 'cl_update_rep_list' in dv.allVars and dv.Get('cl_update_rep_list'):
             chosen_hosting = dv.Get("cl_update_rep_hosting_choice")
             if chosen_hosting:
@@ -590,6 +592,9 @@ class Update(MethodsInterface):
         self.stash_cache(rpath, repdirname)
         rpath_old = f"{rpath}_old"
         makeDirectory(rpath_old)
+        old_hash = PortageState()
+        old_hash.paths = [f'{rpath}']
+        old_hash = old_hash.get_state()
         try:
             if Git.is_git(rpath):
                 self.addProgress()
@@ -617,6 +622,8 @@ class Update(MethodsInterface):
         finally:
             removeDir(rpath_old)
             self.unstash_cache(rpath, repdirname)
+            new_hash = PortageState()
+            new_hash.paths = [f'{rpath}']
         return True
 
     def _regenCache_process(self, progname, repname, cpu_num):
